==> quanyi-center-api-1.4.32-settlement-20250912.091937-3-sources.jar: cn/com/duiba/quanyi/center/api/dto/demand/DemandPaymentInfoDto.java <==
package cn.com.duiba.quanyi.center.api.dto.demand;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import cn.com.duiba.quanyi.center.api.enums.demand.MainStatusEnum;
import cn.com.duiba.quanyi.center.api.enums.workflow.ApprovalStatusEnum;
import lombok.Data;

/**
 * 需求-付款信息
 * @author mybatis generator
 * @date 2024-10-27
 */
@Data
public class DemandPaymentInfoDto implements Serializable {

    private static final long serialVersionUID = 17300036504549320L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 是否逻辑删除, 0-未删除, 1-已删除
     *
     * @see cn.com.duiba.quanyi.center.api.enums.BooleanEnum
     */
    private Integer logicDelete;

    /**
     * 需求主键, tb_demand.id
     */
    private Long demandId;

    /**
     * 审批流主键
     */
    private Long workflowInstanceId;

    /**
     * 付款事由
     */
    private String paymentReason;

    /**
     * 付款金额
     */
    private Long paymentAmount;

    /**
     * 打款公司-选项ID
     */
    private Long paymentCompanyOptionsId;

    /**
     * 打款公司
     */
    private String paymentCompany;

    /**
     * 付款方式-选项ID
     */
    private Long paymentTypeOptionsId;

    /**
     * 付款方式
     */
    private String paymentType;

    /**
     * 收款账户
     */
    private String receivingAccount;

    /**
     * 收款公司
     */
    private String receivingCompany;

    /**
     * 开户行
     */
    private String openingBank;

    /**
     * 实际打款金额
     */
    private Long actualPaymentAmount;

    /**
     * 打款状态，1-待打款，2-已打款
     * @see cn.com.duiba.quanyi.center.api.enums.demand.DemandPaymentStatusEnum
     */
    private Integer paymentStatus;


    /**
     * 需求商品主键
     */
    private Long demandGoodsId;

    /**
     * 审核状态
     * @see ApprovalStatusEnum#getStatus()
     */
    private Integer approvalStatus;

    /**
     * 主状态
     * @see MainStatusEnum#getStatus()
     */
    private Integer mainStatus;


    /**
     * 是否可见: 0-不可见，1-可见
     */
    private Integer showStatus;

    /**
     * 创建人ID
     */
    private Long createOperatorId;

    /**
     * 创建人名称
     */
    private String createOperatorName;

    /**
     * 申请附件
     */
    private String applyAttachment;

    /**
     * 拒绝原因
     */
    private String rejectReason;

    /**
     * 付款-采购凭证
     */
    private List<DemandPurchaseRecordDto> purchaseFileList;

    /**
     * 当前操作人
     */
    private Long currentOperatorId;

    /**
     * 货币类型选项ID
     */
    private Long currencyOptionsId;

    /**
     * 货币类型
     */
    private String currency;

    /**
     * 付款类型，1-垫资打款，2-预付款退款，3-保证金
     * @see cn.com.duiba.quanyi.center.api.enums.demand.PaymentPurposeEnum
     */
    private Integer paymentPurpose;
}

==> quanyi-center-api-1.4.40-settlement-20250922.063847-2-sources.jar: cn/com/duiba/quanyi/center/api/dto/demand/DemandPaymentInfoDto.java <==
package cn.com.duiba.quanyi.center.api.dto.demand;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import cn.com.duiba.quanyi.center.api.enums.demand.MainStatusEnum;
import cn.com.duiba.quanyi.center.api.enums.workflow.ApprovalStatusEnum;
import lombok.Data;

/**
 * 需求-付款信息
 * @author mybatis generator
 * @date 2024-10-27
 */
@Data
public class DemandPaymentInfoDto implements Serializable {

    private static final long serialVersionUID = 17300036504549320L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 是否逻辑删除, 0-未删除, 1-已删除
     *
     * @see cn.com.duiba.quanyi.center.api.enums.BooleanEnum
     */
    private Integer logicDelete;

    /**
     * 需求主键, tb_demand.id
     */
    private Long demandId;

    /**
     * 审批流主键
     */
    private Long workflowInstanceId;

    /**
     * 付款事由
     */
    private String paymentReason;

    /**
     * 付款金额
     */
    private Long paymentAmount;

    /**
     * 打款公司-选项ID
     */
    private Long paymentCompanyOptionsId;

    /**
     * 打款公司
     */
    private String paymentCompany;

    /**
     * 付款方式-选项ID
     */
    private Long paymentTypeOptionsId;

    /**
     * 付款方式
     */
    private String paymentType;

    /**
     * 收款账户
     */
    private String receivingAccount;

    /**
     * 收款公司
     */
    private String receivingCompany;

    /**
     * 开户行
     */
    private String openingBank;

    /**
     * 实际打款金额
     */
    private Long actualPaymentAmount;

    /**
     * 打款状态，1-待打款，2-已打款
     * @see cn.com.duiba.quanyi.center.api.enums.demand.DemandPaymentStatusEnum
     */
    private Integer paymentStatus;


    /**
     * 需求商品主键
     */
    private Long demandGoodsId;

    /**
     * 审核状态
     * @see ApprovalStatusEnum#getStatus()
     */
    private Integer approvalStatus;

    /**
     * 主状态
     * @see MainStatusEnum#getStatus()
     */
    private Integer mainStatus;


    /**
     * 是否可见: 0-不可见，1-可见
     */
    private Integer showStatus;

    /**
     * 创建人ID
     */
    private Long createOperatorId;

    /**
     * 创建人名称
     */
    private String createOperatorName;

    /**
     * 申请附件
     */
    private String applyAttachment;

    /**
     * 拒绝原因
     */
    private String rejectReason;

    /**
     * 付款-采购凭证
     */
    private List<DemandPurchaseRecordDto> purchaseFileList;

    /**
     * 当前操作人
     */
    private Long currentOperatorId;

    /**
     * 货币类型选项ID
     */
    private Long currencyOptionsId;

    /**
     * 货币类型
     */
    private String currency;

    /**
     * 付款类型，1-垫资打款，2-预付款退款，3-保证金
     * @see cn.com.duiba.quanyi.center.api.enums.demand.PaymentPurposeEnum
     */
    private Integer paymentPurpose;

    /**
     * 业务组类型，1-权益，2-数字营销
     * @see cn.com.duiba.quanyi.center.api.enums.contract.BusinessGroupTypeEnum
     */
    private Integer businessGroup;
}
